Package: ADAPT
Title: Analysis of Microbiome Differential Abundance by Pooling Tobit
        Models
Version: 1.6.0
Authors@R: 
    c(person(given="Mukai", family="Wang", email="wangmk@umich.edu", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-1413-1904")),
      person(given="Simon", family="Fontaine", email="simfont@umich.edu", role = "ctb"),
      person(given="Hui", family="Jiang", email="jianghui@umich.edu", role="ctb"),
      person(given="Gen", family="Li", email="ligen@umich.edu", role=c("aut", "ctb")))
Description: ADAPT carries out differential abundance analysis for microbiome metagenomics data in phyloseq format.
  It has two innovations. One is to treat zero counts as left censored and use Tobit models for log count ratios.
  The other is an innovative way to find non-differentially abundant taxa as reference, then use the reference taxa to 
  find the differentially abundant ones.
License: MIT + file LICENSE
Encoding: UTF-8
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.3.2
Imports: Rcpp (>= 1.0.8), RcppArmadillo (>= 0.10.8), RcppParallel (>=
        5.1.5), phyloseq (>= 1.39.0), methods, stats, ggplot2 (>=
        3.4.1), ggrepel (>= 0.9.1)
Suggests: rmarkdown (>= 2.11), knitr (>= 1.37), testthat (>= 3.0.0)
Config/testthat/edition: 3
LinkingTo: Rcpp, RcppArmadillo, RcppParallel
biocViews: DifferentialExpression, Microbiome, Normalization,
        Sequencing, Metagenomics, Software, MultipleComparison
Depends: R (>= 4.1.0)
LazyData: false
VignetteBuilder: knitr
git_url: https://git.bioconductor.org/packages/ADAPT
git_branch: RELEASE_3_23
git_last_commit: 6e0cbf8
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: yes
Packaged: 2026-04-28 20:32:32 UTC; biocbuild
Author: Mukai Wang [aut, cre] (ORCID: <https://orcid.org/0000-0002-1413-1904>),
  Simon Fontaine [ctb],
  Hui Jiang [ctb],
  Gen Li [aut, ctb]
Maintainer: Mukai Wang <wangmk@umich.edu>
