# Generated by roxygen2: do not edit by hand

export(adapt)
exportClasses(DAresult)
exportMethods(plot)
exportMethods(summary)
import(RcppArmadillo)
importFrom(Rcpp,sourceCpp)
importFrom(RcppParallel,RcppParallelLibs)
importFrom(ggplot2,.data)
importFrom(ggplot2,aes)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_vline)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_bw)
importFrom(ggplot2,xlab)
importFrom(ggplot2,ylab)
importFrom(ggrepel,geom_label_repel)
importFrom(methods,setClass)
importFrom(phyloseq,filter_taxa)
importFrom(phyloseq,nsamples)
importFrom(phyloseq,otu_table)
importFrom(phyloseq,prune_samples)
importFrom(phyloseq,sample_data)
importFrom(phyloseq,sample_sums)
importFrom(phyloseq,tax_table)
importFrom(phyloseq,taxa_are_rows)
importFrom(stats,median)
importFrom(stats,model.matrix)
importFrom(stats,optim)
importFrom(stats,p.adjust)
importFrom(stats,pchisq)
importFrom(stats,predict)
importFrom(stats,qchisq)
importFrom(stats,smooth.spline)
useDynLib(ADAPT)
