# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

cr_estim <- function(count_mat, refcounts, Delta, X) {
    .Call('_ADAPT_cr_estim', PACKAGE = 'ADAPT', count_mat, refcounts, Delta, X)
}

